## v8.1.21.post1 (2022-10-12)

### Feat

- **ia**: add classes implementing TagPath (#59)
- **ia**: add TagPathParser class (#58)

## v8.1.21 (2022-09-30)

### Feat

- **system**: add roster functions from 8.1.21 (#52)
- **system**: add util.getModules (#51)

## v8.1.20 (2022-09-22)

## v8.1.20b4 (2022-09-21)

### Feat

- **ia**: add LocaleUtils (#48)
- **java**: add java.text.SimpleDateFormat class (#47)

## v8.1.20b3 (2022-09-13)

### Feat

- **java**: add java.nio Files and Paths (#44)
- **java**: add type hints to all java[x] classes and methods (#40)

### Fix

- **system**: set smtp keyword argument as optional (#43)

## v8.1.20b2 (2022-08-30)

### Feat

- **ia**: add ApplicationScope class (#39)

## v8.1.20b1 (2022-08-26)

### Fix

- **system**: accept String arguments for popup position (#35)

## v8.1.20b0 (2022-08-26)

### Feat

- mirror ignition-api 2022-08-26 (#34)
- mirror ignition-api changes (#30)

### Fix

- **java**: add return value to getOutputStream (#27)

### Refactor

- **system**: change type for `tags` argument (#28)

## v8.1.19b4 (2022-08-05)

### Feat

- **ia**: add fields to SprocCall, SprocArg, and SProcArgKey (#24)

### Fix

- **system**: accept instances of Dataset (#23)

## v8.1.19b3 (2022-08-02)

### Fix

- **ia**: change the return type of dataset columns (#22)

### Refactor

- use java.lang.String for continuation/continuationPoint

## v8.1.19b2 (2022-08-02)

### Fix

- **system**: fix args and return type of tag.query (#21)

## v8.1.19b1 (2022-08-01)

### Fix

- **ia**: make class' properties accessible (#20)

## v8.1.19b0 (2022-07-29)

### Feat

- **system**: add new perspective and tag functions (#17)
- **system**: add constants to __all__ (#16)
- improve type hints (#15)

## v8.1.18a4 (2022-07-09)

## v8.1.18a3 (2022-07-05)

### Feat

- **ia**: implement all LoggerEx functions (#6)

### Fix

- **ci**: remove Python 3.11

## v8.1.18a2 (2022-06-29)

## v8.1.18a1 (2022-06-29)

### Fix

- mypy warnings (#1)
- mypy warnings

## v8.1.18a0 (2022-06-29)
